@@ -25,9 +25,15 @@ def date_to_str(date=None, format_str="%Y-%m-%d %H:%M:%S"):
 
 class BaseDriver(WebDriver):
     def __exit__(self, exc_type, exc_val, exc_tb):
-        self.pwd = os.path.dirname(__file__)
         self.quit()
 
+    def __del__(self):
+        def __del__(self):
+            try:
+                self.quit()
+            except:
+                pass
+
     def open(self, tab_index=0, url=None, timeout=0):
         try:
             handles = self.window_handles  # 获取当前窗口句柄集合（列表类型）
